@@ -38,7 +38,7 @@ private Q_SLOTS:
     void initTestCase()
     {
         QLocale::setDefault(QLocale(u"main"_s));
-        bt::InitLibKTorrent();
+        QVERIFY(bt::InitLibKTorrent());
         bt::InitLog(u"datacheckertest.log"_s, false, true);
     }
 
