@@ -43,6 +43,7 @@ class AnnounceReq;
 
 /*!
     \author Joris Guisson <joris.guisson@gmail.com>
+    \brief Handles everything to do with DHT.
 */
 class DHT : public DHTBase
 {
@@ -57,7 +58,7 @@ public:
     void getPeers(const GetPeersReq &r);
     void announce(const AnnounceReq &r);
     void error(const ErrMsg &r);
-    void timeout(RPCMsg::Ptr r);
+    void timeout(const RPCMsg &r);
 
     /*!
      * A Peer has received a PORT message, and uses this function to alert the DHT of it.
@@ -105,7 +106,7 @@ public:
 private Q_SLOTS:
     void update() override;
     void onResolverResults(net::AddressResolver *ar);
-    void ownNodeLookupFinished(Task *t);
+    void ownNodeLookupFinished(dht::Task *t);
     void expireDatabaseItems();
 
 private:
