@@ -14,8 +14,8 @@ namespace dht
 {
 class RPCCall;
 
-/**
- * Class which objects should derive from, if they want to know the result of a call.
+/*!
+ * \brief Interface for classes that want to know the result of a call.
  */
 class RPCCallListener : public QObject
 {
@@ -23,71 +23,72 @@ public:
     RPCCallListener(QObject *parent);
     ~RPCCallListener() override;
 
-    /**
+    /*!
      * A response was received.
-     * @param c The call
-     * @param rsp The response
+     * \param c The call
+     * \param rsp The response
      */
-    virtual void onResponse(RPCCall *c, RPCMsg::Ptr rsp) = 0;
+    virtual void onResponse(RPCCall *c, RPCMsg *rsp) = 0;
 
-    /**
+    /*!
      * The call has timed out.
-     * @param c The call
+     * \param c The call
      */
     virtual void onTimeout(RPCCall *c) = 0;
 };
 
-/**
- * @author Joris Guisson
+/*!
+ * \author Joris Guisson
+ * \brief Notifies RPCCallListener when an RPCMsg times out or receives a response.
  */
 class RPCCall : public QObject
 {
     Q_OBJECT
 public:
-    RPCCall(RPCMsg::Ptr msg, bool queued);
+    RPCCall(std::unique_ptr<RPCMsg> msg, bool queued);
     ~RPCCall() override;
 
-    /**
+    /*!
      * Called when a queued call gets started. Starts the timeout timer.
      */
     void start();
 
-    /**
+    /*!
      * Called by the server if a response is received.
-     * @param rsp
+     * \param rsp
      */
-    void response(RPCMsg::Ptr rsp);
+    void response(RPCMsg *rsp);
 
-    /**
+    /*!
      * Add a listener for this call
-     * @param cl The listener
+     * \param cl The listener
      */
     void addListener(RPCCallListener *cl);
 
-    /// Get the message type
+    //! Get the message type
     Method getMsgMethod() const;
 
-    /// Get the request sent
-    const RPCMsg::Ptr getRequest() const
+    //! Get the request sent
+    const RPCMsg *getRequest() const
     {
-        return msg;
+        return msg.get();
     }
 
-    /// Get the request sent
-    RPCMsg::Ptr getRequest()
+    //! Get the request sent
+    RPCMsg *getRequest()
     {
-        return msg;
+        return msg.get();
     }
 
 private Q_SLOTS:
     void onTimeout();
 
 Q_SIGNALS:
-    void response(RPCCall *c, RPCMsg::Ptr rsp);
-    void timeout(RPCCall *c);
+    void response(dht::RPCCall *c, dht::RPCMsg *rsp);
+    void timeout(dht::RPCCall *c);
 
 private:
-    RPCMsg::Ptr msg;
+    std::unique_ptr<RPCMsg> msg;
     QTimer timer;
     bool queued;
 };
