@@ -5,7 +5,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "piecedata.h"
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <util/log.h>
 #ifndef Q_OS_WIN
 #include <util/signalcatcher.h>
@@ -40,7 +40,7 @@ void PieceData::unload()
     if (!mapped())
         delete[] ptr;
     else
-        cache_file->unmap(ptr, len);
+        cache_file->unmap(ptr);
     ptr = nullptr;
 }
 
