@@ -29,17 +29,9 @@ bool HttpResponseHeader::parseLine(const QString &line, int number)
         int pos = l.indexOf(QLatin1Char(' '), 9);
         if (pos != -1) {
             _reasonPhr = l.mid(pos + 1);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            _statCode = l.midRef(9, pos - 9).toInt();
-#else
             _statCode = QStringView(l).mid(9, pos - 9).toInt();
-#endif
         } else {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            _statCode = l.midRef(9).toInt();
-#else
             _statCode = QStringView(l).mid(9).toInt();
-#endif
             _reasonPhr.clear();
         }
     } else {
