@@ -4,7 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "trackerinterface.h"
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 namespace bt
 {
