@@ -6,14 +6,15 @@
 #include <QObject>
 #include <QTest>
 
-#include <solid/device.h>
-#include <solid/storageaccess.h>
+#include <Solid/Device>
+#include <Solid/StorageAccess>
 #include <util/error.h>
 #include <util/fileops.h>
 #include <util/functions.h>
 #include <util/log.h>
 
 using namespace bt;
+using namespace Qt::Literals::StringLiterals;
 
 class FileOpsTest : public QObject
 {
@@ -22,7 +23,7 @@ public:
 private Q_SLOTS:
     void initTestCase()
     {
-        bt::InitLog("fileopstest.log");
+        bt::InitLog(u"fileopstest.log"_s);
     }
 
     void cleanupTestCase()
@@ -39,7 +40,7 @@ private Q_SLOTS:
             if (sa->isAccessible()) {
                 QVERIFY(bt::MountPoint(sa->filePath()) == sa->filePath());
 
-                QString path = sa->filePath() + "/some/random/path/test.foobar";
+                QString path = sa->filePath() + "/some/random/path/test.foobar"_L1;
                 Out(SYS_GEN | LOG_DEBUG) << "Testing " << path << endl;
                 QVERIFY(bt::MountPoint(path) == sa->filePath());
             }
