@@ -12,17 +12,19 @@
 #include <QFile>
 #include <QTextStream>
 #include <QThread>
-#include <time.h>
+#include <climits>
+#include <ctime>
 #include <util/functions.h>
 #include <util/log.h>
 #include <util/sha1hash.h>
 
 using namespace bt;
+using namespace Qt::Literals::StringLiterals;
 
 namespace utp
 {
 Connection::TransmissionError::TransmissionError(const char *file, int line)
-    : location(QString("TransmissionError in %1 at line %2\n").arg(file).arg(line))
+    : location(u"TransmissionError in %1 at line %2\n"_s.arg(QLatin1StringView(file)).arg(line))
 {
     Out(SYS_GEN | LOG_DEBUG) << location << endl;
 }
